--- libshout-2.2.2/src/shout.c	2006-06-10 01:09:46.000000000 +0200
+++ libshout-2.2.2.mime/src/shout.c	2008-09-20 13:49:16.000000000 +0200
@@ -113,8 +113,13 @@
 		return NULL;
 	}
 
+	if (shout_set_format(self, LIBSHOUT_DEFAULT_FORMAT) != SHOUTERR_SUCCESS) {
+		shout_free(self);
+
+		return NULL;
+	}
+
 	self->port = LIBSHOUT_DEFAULT_PORT;
-	self->format = LIBSHOUT_DEFAULT_FORMAT;
 	self->protocol = LIBSHOUT_DEFAULT_PROTOCOL;
 
 	return self;
@@ -134,6 +139,7 @@
 	if (self->user) free(self->user);
 	if (self->useragent) free(self->useragent);
 	if (self->audio_info) _shout_util_dict_free (self->audio_info);
+	if (self->mime) free(self->mime);
 
 	free(self);
 }
@@ -710,6 +716,31 @@
 	return self->public;
 }
 
+int shout_set_mime(shout_t *self, const char *mime)
+{
+	if (!self)
+		return SHOUTERR_INSANE;
+
+	if (self->state != SHOUT_STATE_UNCONNECTED)
+		return SHOUTERR_CONNECTED;
+
+	if (self->mime)
+		free(self->mime);
+
+	if (! (self->mime = _shout_util_strdup (mime)))
+		return self->error = SHOUTERR_MALLOC;
+
+	return self->error = SHOUTERR_SUCCESS;
+}
+
+const char *shout_get_mime(shout_t *self)
+{
+	if (!self)
+		return NULL;
+
+	return self->mime;
+}
+
 int shout_set_format(shout_t *self, unsigned int format)
 {
 	if (!self)
@@ -723,7 +754,15 @@
 
 	self->format = format;
 
-	return self->error = SHOUTERR_SUCCESS;
+	/* Set decent value for mime. */
+	switch (format) {
+		case SHOUT_FORMAT_OGG:
+			return shout_set_mime(self,SHOUT_OGG_MIME);
+		case SHOUT_FORMAT_MP3:
+			return shout_set_mime(self,SHOUT_MP3_MIME);
+	}
+
+	return self->error = SHOUTERR_INSANE;
 }
 
 unsigned int shout_get_format(shout_t* self)
@@ -1116,9 +1155,7 @@
 		}
 		if (self->useragent && queue_printf(self, "User-Agent: %s\r\n", self->useragent))
 			break;
-		if (self->format == SHOUT_FORMAT_OGG && queue_printf(self, "Content-Type: application/ogg\r\n"))
-			break;
-		if (self->format == SHOUT_FORMAT_MP3 && queue_printf(self, "Content-Type: audio/mpeg\r\n"))
+		if (self->mime && queue_printf(self, "Content-Type: %s\r\n", self->mime))
 			break;
 		if (queue_printf(self, "ice-name: %s\r\n", self->name ? self->name : "no name"))
 			break;
--- libshout-2.2.2/src/shout_private.h	2005-06-27 23:33:25.000000000 +0200
+++ libshout-2.2.2.mime/src/shout_private.h	2008-09-20 13:51:20.000000000 +0200
@@ -65,6 +65,8 @@
 	unsigned int protocol;
 	/* type of data being sent */
 	unsigned int format;
+	/* Mime type for data */
+	char *mime;
 	/* audio encoding parameters */
 	util_dict *audio_info;
 
--- libshout-2.2.2/include/shout/shout.h.in	2005-06-27 23:33:21.000000000 +0200
+++ libshout-2.2.2.mime/include/shout/shout.h.in	2008-09-20 13:53:11.000000000 +0200
@@ -44,6 +44,10 @@
 /* backward-compatibility alias */
 #define SHOUT_FORMAT_VORBIS	SHOUT_FORMAT_OGG
 
+/* Default mime types */
+#define SHOUT_OGG_MIME          "application/ogg"
+#define SHOUT_MP3_MIME          "audio/mpeg"
+
 #define SHOUT_PROTOCOL_HTTP		(0)
 #define SHOUT_PROTOCOL_XAUDIOCAST	(1)
 #define SHOUT_PROTOCOL_ICY		(2)
@@ -135,6 +139,14 @@
 int shout_set_format(shout_t *self, unsigned int format);
 unsigned int shout_get_format(shout_t *self);
 
+/* Set the data's mime type.
+ * This value is set to a decent value by 
+ * shout_set_format. Using this function 
+ * is optional and should be done after
+ * calling shout_set_format. */
+int shout_set_mime(shout_t *self, const char *mime);
+const char *shout_get_mime(shout_t *self);
+
 /* takes a SHOUT_PROTOCOL_xxxxx argument */
 int shout_set_protocol(shout_t *self, unsigned int protocol);
 unsigned int shout_get_protocol(shout_t *self);
